# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["DexGetParams"]


class DexGetParams(TypedDict, total=False):
    page: int
    """page through results Default value: 1"""
